Registracija | OiRA

Temos

# Registracija

## Kodėl turiu užsiregistruoti?

Norėdami pradėti pirmąjį savo rizikos vertinimą, pirmiausia turėsite susikurti OiRA paskyrą - tai atliekama paprastai ir greitai.

Užsiregistravę galėsite bet kada prisijungti ir prieiti prie savo duomenų, tęsti ankstesnius vertinimus ar pradėti naujus.

Užsiregistravus OiRA sistema gali išsaugoti visas jūsų sesijas ir jūsų duomenys visada bus prieinami.

Susipažinkite su mūsų privatumo politika ir sužinokite, kaip tvarkome jūsų asmens duomenis.

## Kuo skiriasi vartotojo registracija ir bandomoji sesija?

Bandomosios sesijos metu suinteresuotosios šalys, prieš nuspręsdamos registruotis, gali susipažinti su šia priemone. Tačiau per bandomąją sesiją jūsų duomenys neišsaugomi ir vėliau nebeturėsite prieigos prie savo suvestos informacijos. Bandomosios sesijos metu negalite spausdinti jokių ataskaitų, o paskyros užregistravimas jums leis parengti visus rizikos vertinimo dokumentus.

## Registruoti naują paskyrą

Ar tai pirmasis jūsų apsilankymas? Prieš pradėdami, atlikite šiuos paprastus veiksmus:

1.) Kad atsidarytumėte registracijos formą, spustelėkite „Registruotis“.

Registracijos forma

2.) Įrašykite savo e. pašto adresą ir norimą slaptažodį (du kartus)

3.) Spustelėję mygtuką „Toliau“ užregistruokite savo naująją paskyrą.

4.) Norėdami tęsti, perskaitykite ir patvirtinkite privatumo politikos pareiškimą

Dabar prisijungsite prie OiRA sistemos.

## Prisijungimas prie esamos paskyros

Jei jau esate užsiregistravęs, prie savo paskyros junkitės taip:

1.) Atidarykite prisijungimo formą. Kiekvieną kartą bandant prisijungti prie OiRA, pasirodys prisijungimo formos nuoroda, kurią matysite tol, kol prisijungsite.

Prisijungimo forma

2.) Įrašykite savo e. pašto adresą ir slaptažodį.

3.) Prisijunkite paspaudę „Prisijungti“.

Kai tik prisijungsite, apačioje pamatysite langą. Čia galite pradėti naują rizikos vertinimą arba tęsti anksčiau pradėtą rizikos vertinimą.

Valdymo skydas

Pradėkite naują rizikos vertinimą suteikdami jam pavadinimą (pvz., mano bendrovė 2018-07-03) arba atsidarykite ankstesnį rizikos vertinimą Visi jūsų rizikos vertinimai saugomi, kad galėtumėte jais naudotis ateityje, nebent nuspręstumėte juos ištrinti.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More